@@ -902,8 +902,9 @@ class BaseExperiment:
         if not fetch_only_dir:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}' 
             extension_candidates = ["ckpt", "sav"]
-            for ckpt_dir in os.listdir(ckpt_path):
-                ckpt_extension_type = str(ckpt_dir).split('.')[-1]
+            for ckpt in os.listdir(ckpt_path):
+                ckpt_extension_type = str(ckpt).split('.')[-1]
+                ckpt_dir = f'{ckpt_path}/{ckpt}'
                 if ckpt_extension_type not in extension_candidates:
                     raise ValueError(f"Wrong file extension {ckpt_extension_type} for the checkpoint. It should be in {extension_candidates}")
                 if ckpt_extension_type == "sav":
@@ -918,9 +919,9 @@ class BaseExperiment:
         else:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}'
             extension_candidates = ["ckpt", "sav"]
-            for ckpt_dir in os.listdir(ckpt_path):
-                if os.path.exists(ckpt_dir):
-                    ckpt_dir = ckpt_dir
+            for ckpt in os.listdir(ckpt_path):
+                if os.path.exists(ckpt):
+                    ckpt_dir = ckpt
             return str(ckpt_dir), info
         
     
